---
name: Feature request
about: Propose a new feature or a change to an existing feature.
title: ''
labels: 'feature'
assignees: ''

---
<!--
For the Feature Request,
Include the following:
------------------------
What would you like changed/added and why?
What would be the benefit?
Does the change make something easier to use?
-->
